require 'yaml'

class MicroboshHacker::HealthMonitorConfig
  attr_reader :config_path, :opts

  REQUIRED_OPTS= %i{ email_recipients from host port domain}
  OPTIONAL_OPTS= %i{ auth user password interval}
  AVAILABLE_OPTS= REQUIRED_OPTS+ OPTIONAL_OPTS

  def initialize(config_path, opts = {})
    @config_path=config_path
    @opts=opts

    raise "Missing options: #{(REQUIRED_OPTS - @opts.keys).join(', ')}" unless (REQUIRED_OPTS - @opts.keys).empty?
    opts.each_pair do |k, v|
      raise "Nil or empty option: #{k}" if v.nil? || v.to_s.empty?
    end
  end

  def to_yaml
    config = ::YAML.load_file(config_path)
    config['plugins'].unshift(
      {
        'name' => 'email',
        'events' => [ 'alert' ],
        'options' => {
          'recipients' => opts[:email_recipients],
          'smtp' => {
            'from' => opts[:from],
            'host' => opts[:host],
            'port' => opts[:port],
            'domain' => opts[:domain]
          }
        }
      }
    )

      # auth: 'plain
      # user: user
      # password: pass123
      # interval:1
    config.to_yaml
  end
end
